Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: ui/views/window/dialog_delegate.h

Issue 11571023: Move ash/wm's DialogFrameView to ui/views/window; etc. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Reorder DialogDelegate functions; inline Get*Params into WidgetExample::ButtonPressed; etc. Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/window/dialog_client_view.cc ('k') | ui/views/window/dialog_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/window/dialog_delegate.h
diff --git a/ui/views/window/dialog_delegate.h b/ui/views/window/dialog_delegate.h
index 59319c0b85c8925bd5f5d650e2a840975a9f2e78..67eb954b34678c3e21ddc76e2f8fd66fd51575f0 100644
--- a/ui/views/window/dialog_delegate.h
+++ b/ui/views/window/dialog_delegate.h
@@ -14,7 +14,6 @@
namespace views {
class DialogClientView;
-class View;
///////////////////////////////////////////////////////////////////////////////
//
@@ -28,10 +27,11 @@ class View;
///////////////////////////////////////////////////////////////////////////////
class VIEWS_EXPORT DialogDelegate : public WidgetDelegate {
public:
- virtual DialogDelegate* AsDialogDelegate() OVERRIDE;
-
virtual ~DialogDelegate();
+ // Returns whether to use the new dialog style.
+ static bool UseNewStyle();
+
// Returns a mask specifying which of the available DialogButtons are visible
// for the dialog. Note: If an OK button is provided, you should provide a
// CANCEL button. A dialog box with just an OK button is frowned upon and
@@ -58,10 +58,6 @@ class VIEWS_EXPORT DialogDelegate : public WidgetDelegate {
// Returns whether the specified dialog button is visible.
virtual bool IsDialogButtonVisible(ui::DialogButton button) const;
- // Returns whether to use chrome style for the button strip (like WebUI). If
- // false, native style padding is used.
- virtual bool UseChromeStyle() const;
-
// Returns whether accelerators are enabled on the button. This is invoked
// when an accelerator is pressed, not at construction time. This
// returns true.
@@ -95,9 +91,11 @@ class VIEWS_EXPORT DialogDelegate : public WidgetDelegate {
virtual bool Accept(bool window_closing);
virtual bool Accept();
// Overridden from WindowDelegate:
virtual View* GetInitiallyFocusedView() OVERRIDE;
+ virtual DialogDelegate* AsDialogDelegate() OVERRIDE;
virtual ClientView* CreateClientView(Widget* widget) OVERRIDE;
+ virtual NonClientFrameView* CreateNonClientFrameView(Widget* widget) OVERRIDE;
// Called when the window has been closed.
virtual void OnClose() {}
@@ -124,6 +122,7 @@ class VIEWS_EXPORT DialogDelegateView : public DialogDelegate,
// Overridden from DialogDelegate:
virtual Widget* GetWidget() OVERRIDE;
virtual const Widget* GetWidget() const OVERRIDE;
+ virtual View* GetContentsView() OVERRIDE;
private:
DISALLOW_COPY_AND_ASSIGN(DialogDelegateView);
« no previous file with comments | « ui/views/window/dialog_client_view.cc ('k') | ui/views/window/dialog_delegate.cc » ('j') | no next file with comments »
@@ -95,9 +91,11 @@ class VIEWS_EXPORT DialogDelegate : public WidgetDelegate {
virtual bool Accept(bool window_closing);
virtual bool Accept();
- // Overridden from WindowDelegate:
+ // Overridden from WidgetDelegate:
virtual View* GetInitiallyFocusedView() OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698